@@ -48,7 +48,9 @@ bool AdaptDefinitionSignatureAssistant::isUseful() {
 }
 
 AdaptDefinitionSignatureAssistant::AdaptDefinitionSignatureAssistant(KTextEditor::View* view, KTextEditor::Range inserted)
-:m_view(view) {
+: m_view(view)
+, m_editingDefinition(false)
+{
   connect(KDevelop::ICore::self()->languageController()->backgroundParser(), SIGNAL(parseJobFinished(KDevelop::ParseJob*)), SLOT(parseJobFinished(KDevelop::ParseJob*)));
   m_document = KDevelop::IndexedString(view->document()->url());
   
