@@ -685,6 +685,80 @@ private slots:
     QVERIFY(hasKind(funcAst, AST::Kind_InitDeclarator));
   }
 
+  void testSwitchStatement()
+  {
+    int problemCount = control.problems().count();
+    pool mem_pool;
+
+    QByteArray switchTest("int main() { switch(0); }");
+    parse(switchTest, &mem_pool);
+    QCOMPARE(control.problems().count(), ++problemCount);
+    QByteArray switchTest2("int main() { switch (0) case 0: if (true) ; else return 1; }");
+    parse(switchTest2, &mem_pool);
+    QCOMPARE(control.problems().count(), ++problemCount);
+    QByteArray switchTest3("int main() { switch (0) { case 0: if (true) ; else return 1; } }");
+    parse(switchTest3, &mem_pool);
+    QCOMPARE(control.problems().count(), ++problemCount);
+    QByteArray switchTest4("int main() { switch (0) while(true) return false; }");
+    parse(switchTest4, &mem_pool);
+    QCOMPARE(control.problems().count(), ++problemCount);
+    QByteArray switchTest5("int main() { switch (0) { case 0: return 0; } }");
+    parse(switchTest5, &mem_pool);
+    QCOMPARE(control.problems().count(), ++problemCount);
+  }
+
+  void testNamedOperators_data()
+  {
+    QTest::addColumn<QString>("code");
+    QTest::newRow("xor") << "int i = 1 xor 2;";
+    QTest::newRow("bitand") << "int i = 1 bitand 2;";
+    QTest::newRow("bitor") << "int i = 1 bitor 2;";
+    QTest::newRow("or") << "int i = 1 or 2;";
+    QTest::newRow("and") << "int i = 1 and 2;";
+    QTest::newRow("compl") << "int i = compl 2;";
+    QTest::newRow("not") << "int i = not 2;";
+    QTest::newRow("xor_eq") << "int i = 1; i xor_eq 2;";
+    QTest::newRow("and_eq") << "int i = 1; i and_eq 2;";
+    QTest::newRow("or_eq") << "int i = 1; i or_eq 2;";
+    QTest::newRow("not_eq") << "int i = 1 not_eq 2;";
+  }
+
+  void testNamedOperators()
+  {
+    pool mem_pool;
+
+    QFETCH(QString, code);
+    code = "int main() { " + code + " }\n";
+    parse(code.toLocal8Bit(), &mem_pool);
+    QVERIFY(control.problems().isEmpty());
+  }
+
+  void testOperators_data()
+  {
+    QTest::addColumn<QString>("code");
+    QTest::newRow("xor") << "int i = 1 ^ 2;";
+    QTest::newRow("bitand") << "int i = 1 & 2;";
+    QTest::newRow("bitor") << "int i = 1 | 2;";
+    QTest::newRow("or") << "int i = 1 || 2;";
+    QTest::newRow("and") << "int i = 1 && 2;";
+    QTest::newRow("compl") << "int i = ~2;";
+    QTest::newRow("not") << "int i = !2;";
+    QTest::newRow("xor_eq") << "int i = 1; i ^= 2;";
+    QTest::newRow("and_eq") << "int i = 1; i &= 2;";
+    QTest::newRow("or_eq") << "int i = 1; i |= 2;";
+    QTest::newRow("not_eq") << "int i = 1 != 2;";
+  }
+
+  void testOperators()
+  {
+    pool mem_pool;
+
+    QFETCH(QString, code);
+    code = "int main() { " + code + " }\n";
+    parse(code.toLocal8Bit(), &mem_pool);
+    QVERIFY(control.problems().isEmpty());
+  }
+
 private:
   ParseSession* lastSession;
 
