@@ -137,9 +137,9 @@ static char const * const _S_token_texts[] = {
   "__typeof",
   "&&",
   "&=",
-  ">",
+  "->",
   "asm",
-  "==",
+  "=",
   "auto",
   "&",
   "|",
@@ -197,7 +197,7 @@ static char const * const _S_token_texts[] = {
   "preproc",
   "private",
   "protected",
-  "ptrmem",
+  ".*",
   "public",
   "register",
   "reinterpret_cast",
@@ -216,6 +216,7 @@ static char const * const _S_token_texts[] = {
   "switch",
   "template",
   "this",
+  "thread_local",
   "throw",
   "true",
   "try",
