@@ -68,6 +68,16 @@ MakeJob::MakeJob(MakeBuilder* builder, KDevelop::ProjectBaseItem* item, CommandT
     setObjectName(title);
 }
 
+MakeJob::~MakeJob()
+{
+    if(!m_killed && m_process && m_process->state() != KProcess::NotRunning)
+    {
+        m_process->kill();
+        m_process->waitForFinished();
+    }
+    Q_ASSERT(!m_process || m_process->state() == KProcess::NotRunning);
+}
+
 void MakeJob::start()
 {
     kDebug(9037) << "Building with make" << m_command << m_overrideTarget;
@@ -307,6 +317,7 @@ bool MakeJob::doKill()
     model()->addLine( i18n("*** Aborted ***") );
     m_killed = true;
     m_process->kill();
+    m_process->waitForFinished();
     return true;
 }
 
